==> ingdao-0.0.6.tar.gz: lib/dataflow/control/dfquery.dart <==
import '../field/dfbasefield.dart';
import 'dfqueryentityjoin.dart';
import 'dfquerycriteriagroup.dart';
import 'dfqueryorderby.dart';
import 'dfquerypaging.dart';
import 'package:meta/meta.dart';

const DFQUERYPURPOSE_ADD_NAME = 'add';
const DFQUERYPURPOSE_FETCH_NAME = 'fetch';
const DFQUERYPURPOSE_UPDATE_WHOLE_ENTITY_ATTRS_NAME = 'update_whole_entity_attrs';
const DFQUERYPURPOSE_UPDATE_SOME_ENTITY_ATTRS_NAME = 'update_some_entity_attrs';
const DFQUERYPURPOSE_DELETE = 'delete';
const DFQUERYPURPOSE_OFFLINE_CHANGE = 'offlinechange';

enum DfQueryPurpose {
  FETCH,
  ADD,
  UPDATE_WHOLE_ENTITY_ATTRS,
  UPDATE_SOME_ENTITY_ATTRS,
  DELETE,
  OFFLINE_CHANGE
}

extension DfQueryPurposeExtension on DfQueryPurpose {

  String get name {
    switch (this) {
      case DfQueryPurpose.ADD:
        return DFQUERYPURPOSE_ADD_NAME;
      case DfQueryPurpose.FETCH:
        return DFQUERYPURPOSE_FETCH_NAME;
      case DfQueryPurpose.UPDATE_WHOLE_ENTITY_ATTRS:
        return DFQUERYPURPOSE_UPDATE_WHOLE_ENTITY_ATTRS_NAME;
      case DfQueryPurpose.UPDATE_SOME_ENTITY_ATTRS:
        return DFQUERYPURPOSE_UPDATE_SOME_ENTITY_ATTRS_NAME;
      case DfQueryPurpose.DELETE:
        return DFQUERYPURPOSE_DELETE;
      case DfQueryPurpose.OFFLINE_CHANGE :
        return DFQUERYPURPOSE_OFFLINE_CHANGE;                                
      default:
        return null;
    }
  }

  String desp() {
    return this.name;
  }
}

class DfQuery {
  Map<DfBaseField, dynamic> fields;
  DfQueryEntityJoin entityJoin;
  DfQueryCriteriaGroup criteriaGroup;
  List<DfQueryOrderBy> orderBy;
  List<DfBaseField> groupBy;
  Paging paging;
  DfQueryPurpose purpose;

  DfQuery({@required this.purpose, @required dynamic queryFields, @required this.entityJoin, this.criteriaGroup, this.orderBy, this.groupBy, this.paging}) {
    if (queryFields is Map) {
      fields = queryFields;  
    }
    else {
      fields = Map<DfBaseField, dynamic>();
      List<DfBaseField> arrFields = queryFields;
      arrFields.forEach((field) => fields[field] = null);
    }
  }
}

==> ingdao-0.0.7.tar.gz: lib/dataflow/control/dfquery.dart <==
import '../field/dfbasefield.dart';
import 'dfqueryentityjoin.dart';
import 'dfquerycriteriagroups.dart';
import 'dfqueryorderby.dart';
import 'dfquerypaging.dart';
import 'package:meta/meta.dart';

const DFQUERYPURPOSE_ADD_NAME = 'add';
const DFQUERYPURPOSE_FETCH_NAME = 'fetch';
const DFQUERYPURPOSE_UPDATE_WHOLE_ENTITY_ATTRS_NAME = 'update_whole_entity_attrs';
const DFQUERYPURPOSE_UPDATE_SOME_ENTITY_ATTRS_NAME = 'update_some_entity_attrs';
const DFQUERYPURPOSE_DELETE = 'delete';
const DFQUERYPURPOSE_OFFLINE_CHANGE = 'offlinechange';

enum DfQueryPurpose {
  FETCH,
  ADD,
  UPDATE_WHOLE_ENTITY_ATTRS,
  UPDATE_SOME_ENTITY_ATTRS,
  DELETE,
  OFFLINE_CHANGE
}

extension DfQueryPurposeExtension on DfQueryPurpose {

  String get name {
    switch (this) {
      case DfQueryPurpose.ADD:
        return DFQUERYPURPOSE_ADD_NAME;
      case DfQueryPurpose.FETCH:
        return DFQUERYPURPOSE_FETCH_NAME;
      case DfQueryPurpose.UPDATE_WHOLE_ENTITY_ATTRS:
        return DFQUERYPURPOSE_UPDATE_WHOLE_ENTITY_ATTRS_NAME;
      case DfQueryPurpose.UPDATE_SOME_ENTITY_ATTRS:
        return DFQUERYPURPOSE_UPDATE_SOME_ENTITY_ATTRS_NAME;
      case DfQueryPurpose.DELETE:
        return DFQUERYPURPOSE_DELETE;
      case DfQueryPurpose.OFFLINE_CHANGE :
        return DFQUERYPURPOSE_OFFLINE_CHANGE;                                
      default:
        return null;
    }
  }

  String desp() {
    return this.name;
  }
}

class DfQuery {
  Map<DfBaseField, dynamic> fields;
  DfQueryEntityJoin entityJoin;
  DfQueryCriteriaGroups criteriaGroups;
  List<DfQueryOrderBy> orderBy;
  List<DfBaseField> groupBy;
  Paging paging;
  DfQueryPurpose purpose;

  DfQuery({@required this.purpose, @required dynamic queryFields, @required this.entityJoin, this.criteriaGroups, this.orderBy, this.groupBy, this.paging}) {
    if (queryFields is Map) {
      fields = queryFields;  
    }
    else if (queryFields is DfBaseField) {
      fields = Map<DfBaseField, dynamic>();
      List<DfBaseField> arrFields = [queryFields];
      arrFields.forEach((field) => fields[field] = null);
    }
    else {
      fields = Map<DfBaseField, dynamic>();
      List<DfBaseField> arrFields = queryFields;
      arrFields.forEach((field) => fields[field] = null);
    }
  }
}
